==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/encryption_ng/translations/encryption_ng_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation>Ve výchozím nastavení zašifrovat</translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation>Zašifrovat po obdržení šifrované zprávy</translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionActions</name>
    <message>
        <source>Encrypt</source>
        <translation>Zašifrovat</translation>
    </message>
    <message>
        <source>Send My Public Key</source>
        <translation>Poslat můj veřejný klíč</translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation>Žádný veřejný klíč není dostupný</translation>
    </message>
    <message>
        <source>Generate Encryption Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished">Šifrování</translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation type="unfinished">Nelze vytvořit klíče. Prověřte, zda je nahrán modul encryption_simlite</translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation type="unfinished">Klíč existuje. Chcete jej přepsat?</translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation type="unfinished">Klíče byly vytvořeny</translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation type="unfinished">Chyba při vytváření klíčů</translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation>Veřejný klíč byl poslán: %1 (%2)</translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished">Šifrování</translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation type="unfinished">Přídavný modul QCA OSSL pro libqca2 není přítomen!</translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation>Kamarád %1 vám posílá svůj veřejný klíč.
Chcete jej uložit?</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/encryption_ng/translations/encryption_ng_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation>Ve výchozím nastavení zašifrovat</translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation>Zašifrovat po obdržení šifrované zprávy</translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnableEncryptionActionDescription</name>
    <message>
        <source>Encrypt</source>
        <translation>Zašifrovat</translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation>Veřejný klíč byl poslán: %1 (%2)</translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation type="unfinished">Šifrování</translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation type="unfinished">Přídavný modul QCA OSSL pro libqca2 není přítomen!</translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation>Kamarád %1 vám posílá svůj veřejný klíč.
Chcete jej uložit?</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
</context>
<context>
    <name>GenerateKeysActionDescription</name>
    <message>
        <source>Generate Encryption Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished">Šifrování</translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation type="unfinished">Nelze vytvořit klíče. Prověřte, zda je nahrán modul encryption_simlite</translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation type="unfinished">Klíč existuje. Chcete jej přepsat?</translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation type="unfinished">Klíče byly vytvořeny</translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation type="unfinished">Chyba při vytváření klíčů</translation>
    </message>
</context>
<context>
    <name>SendPublicKeyActionDescription</name>
    <message>
        <source>Send My Public Key</source>
        <translation>Poslat můj veřejný klíč</translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation>Žádný veřejný klíč není dostupný</translation>
    </message>
</context>
</TS>
